use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Metabase
dir
errstr
mx
Adam
Foxson
afoxson
David
Golden
dagolden
Kirrily
Skud
Robert
skud
Ricardo
Signes
rjbs
Richard
Soderberg
rsod
Kurt
Starsinic
Authors
and
Contributors
Andreas
Koenig
andk
Ed
mohawk2
Tatsuhiko
Miyagawa
miyagawa
Vincent
Pit
perl
lib
Test
Reporter
Transport
File
Null
